@@ -12,7 +12,6 @@ specific language governing permissions and limitations under the License.
 """
 
 import collections
-import logging
 
 from django.contrib.auth import get_user_model
 from django.utils.module_loading import import_string
@@ -232,7 +231,7 @@ try:
 except ImportError as err:
     from blueapps.dummy.dummy_client import DummyClient
     client = DummyClient(err)
-    backend_client = DummyClient
+    backend_client = DummyClient  # pylint: disable=invalid-name
 
 
 def get_client_by_user(user_or_username):
